
#ifndef FCITXQTWIDGETSADDONS_EXPORT_H
#define FCITXQTWIDGETSADDONS_EXPORT_H

#ifdef FCITXQTWIDGETSADDONS_STATIC_DEFINE
#  define FCITXQTWIDGETSADDONS_EXPORT
#  define FCITXQTWIDGETSADDONS_NO_EXPORT
#else
#  ifndef FCITXQTWIDGETSADDONS_EXPORT
#    ifdef FcitxQt5WidgetsAddons_EXPORTS
        /* We are building this library */
#      define FCITXQTWIDGETSADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define FCITXQTWIDGETSADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef FCITXQTWIDGETSADDONS_NO_EXPORT
#    define FCITXQTWIDGETSADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef FCITXQTWIDGETSADDONS_DEPRECATED
#  define FCITXQTWIDGETSADDONS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef FCITXQTWIDGETSADDONS_DEPRECATED_EXPORT
#  define FCITXQTWIDGETSADDONS_DEPRECATED_EXPORT FCITXQTWIDGETSADDONS_EXPORT FCITXQTWIDGETSADDONS_DEPRECATED
#endif

#ifndef FCITXQTWIDGETSADDONS_DEPRECATED_NO_EXPORT
#  define FCITXQTWIDGETSADDONS_DEPRECATED_NO_EXPORT FCITXQTWIDGETSADDONS_NO_EXPORT FCITXQTWIDGETSADDONS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef FCITXQTWIDGETSADDONS_NO_DEPRECATED
#    define FCITXQTWIDGETSADDONS_NO_DEPRECATED
#  endif
#endif

#endif /* FCITXQTWIDGETSADDONS_EXPORT_H */
