
#ifndef FCITXQTDBUSADDONS_EXPORT_H
#define FCITXQTDBUSADDONS_EXPORT_H

#ifdef FCITXQTDBUSADDONS_STATIC_DEFINE
#  define FCITXQTDBUSADDONS_EXPORT
#  define FCITXQTDBUSADDONS_NO_EXPORT
#else
#  ifndef FCITXQTDBUSADDONS_EXPORT
#    ifdef FcitxQt5DBusAddons_EXPORTS
        /* We are building this library */
#      define FCITXQTDBUSADDONS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define FCITXQTDBUSADDONS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef FCITXQTDBUSADDONS_NO_EXPORT
#    define FCITXQTDBUSADDONS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef FCITXQTDBUSADDONS_DEPRECATED
#  define FCITXQTDBUSADDONS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef FCITXQTDBUSADDONS_DEPRECATED_EXPORT
#  define FCITXQTDBUSADDONS_DEPRECATED_EXPORT FCITXQTDBUSADDONS_EXPORT FCITXQTDBUSADDONS_DEPRECATED
#endif

#ifndef FCITXQTDBUSADDONS_DEPRECATED_NO_EXPORT
#  define FCITXQTDBUSADDONS_DEPRECATED_NO_EXPORT FCITXQTDBUSADDONS_NO_EXPORT FCITXQTDBUSADDONS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef FCITXQTDBUSADDONS_NO_DEPRECATED
#    define FCITXQTDBUSADDONS_NO_DEPRECATED
#  endif
#endif

#endif /* FCITXQTDBUSADDONS_EXPORT_H */
